#[repr(u8)]pub enum Cfen {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
MAC control frames with any opcode other than 0x0001 (pause frame) are accepted and forwarded to the client interface.
ONE = 1
MAC control frames with any opcode other than 0x0001 (pause frame) are silently discarded.
Implementations