#[repr(u8)]pub enum Dbswp {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
The buffer descriptor bytes are not swapped to support big-endian devices.
ONE = 1
The buffer descriptor bytes are swapped to support little-endian devices.
Implementations