#[repr(u8)]pub enum Ipchk {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
Checksum is not inserted.
ONE = 1
If an IP frame is transmitted, the checksum is inserted automatically. The IP header checksum field must be cleared. If a non-IP frame is transmitted the frame is not modified.
Implementations