#[repr(u8)]pub enum Peren {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
Disable.
ONE = 1
A period event interrupt can be generated (EIR[TS_TIMER]) and the event signal output is asserted when the timer wraps around according to the periodic setting ATPER. The timer period value must be set before setting this bit. Not all devices contain the event signal output. See the chip configuration details.
Implementations