nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Slave

Enum Slave 

#[repr(u8)]
pub enum Slave { ZERO = 0, ONE = 1, }

Variants



ZERO = 0

The timer is active and all configuration fields in this register are relevant.



ONE = 1

The internal timer is disabled and the externally provided timer value is used. All other fields, except CAPTURE, in this register have no effect. CAPTURE can still be used to capture the current timer value.

Implementations

Source

impl Slave

pub const fn from_bits(val: u8) -> Slave

pub const fn to_bits(self) -> u8