#[repr(u8)]pub enum TaccShift16 {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
Disabled.
ONE = 1
Indicates to the transmit data FIFO that the written frames contain two additional octets before the frame data. This means the actual frame begins at bit 16 of the first word written into the FIFO. This function allows putting the frame payload on a 32-bit boundary in memory, as the 14-byte Ethernet header is extended to a 16-byte header.
Implementations
Sourceimpl TaccShift16
impl TaccShift16