#[repr(u8)]pub enum Ipdis {
ZERO = 0,
ONE = 1,
}Variants
ZERO = 0
Frames with wrong IPv4 header checksum are not discarded.
ONE = 1
If an IPv4 frame is received with a mismatching header checksum, the frame is discarded. IPv6 has no header checksum and is not affected by this setting. Discarding is only available when the RX FIFO operates in store and forward mode (RSFL cleared).
Implementations